==> org-lsst-ccs-subsystem-fcs-main-4.0.2-sources.jar: org/lsst/ccs/subsystems/fcs/singlefiltertest/CanOpenLatchActuatorModule.java <==

package org.lsst.ccs.subsystems.fcs.singlefiltertest;

import org.lsst.ccs.commons.annotations.ConfigurationParameter;
import org.lsst.ccs.subsystems.fcs.drivers.CanOpenDAC;

/**
 * 
 * Used only for the single-filter-test hardware.
 * 
 * This is a model for a motor which locks or unlocks a latch. The motor is
 * driven by a CAN-CBX-AO412. We sent to the CAN-CBX-AO412 a current value.
 *
 * @author virieux
 */
public class CanOpenLatchActuatorModule extends LatchActuatorModule {

    /**
     * The DAC which controls the motor.
     */
    private CanOpenDAC dac;

    /**
     * This is the name of the DAC on which the actuator is plugged. Used in the
     * groovy file and in initModule.
     *
     */
    @ConfigurationParameter(isFinal=true,
            description="The name of the DIO where the filter sensors are plugged.")
    private String dacName;

    /**
     * The numero of analog output where we send the value of the current to the
     * motor. (variable)
     */
    @ConfigurationParameter
    private int numOfAnalogOutputForSpeedVoltage;

    /**
     * The numero of analog output where we send the value of the current limit
     * to the motor. current limit (fixed)
     */
    @ConfigurationParameter
    private int numOfAnalogOutputForCurrentLimit;

    /**
     * Build a new CanOpenLatchActuatorModule
     * @param currentLimitInVolt
     * @param speedVoltageInVolt
     * @param speedVoltageMinValue
     * @param speedVoltageMaxValue
     * @param dacName
     * @param numOfAnalogOutputForSpeedVoltage
     * @param numOfAnalogOutputForCurrentLimit 
     */
    public CanOpenLatchActuatorModule(
            double currentLimitInVolt,
            double speedVoltageInVolt,
            int speedVoltageMinValue,
            int speedVoltageMaxValue,
            String dacName,
            int numOfAnalogOutputForSpeedVoltage,
            int numOfAnalogOutputForCurrentLimit) {
        super(currentLimitInVolt, speedVoltageInVolt, speedVoltageMinValue, speedVoltageMaxValue);
        this.dacName = dacName;
        this.numOfAnalogOutputForSpeedVoltage = numOfAnalogOutputForSpeedVoltage;
        this.numOfAnalogOutputForCurrentLimit = numOfAnalogOutputForCurrentLimit;
    }

    public void setNumOfAnalogOutputForSpeedVoltage(int numOfAnalogOutputForSpeedVoltage) {
        this.numOfAnalogOutputForSpeedVoltage = numOfAnalogOutputForSpeedVoltage;
    }

    public void setNumOfAnalogOutputForCurrentLimit(int numOfAnalogOutputForCurrentLimit) {
        this.numOfAnalogOutputForCurrentLimit = numOfAnalogOutputForCurrentLimit;
    }

    @Override
    public void initModule() {
        this.dac = (CanOpenDAC) getComponentLookup().getComponentByName(dacName);
    }

    @Override
    public String open()  {

        //set the current limit
        int currentLimitInDecimal = (int) (this.currentLimitInVolt * CanOpenDAC.bitOverVolts);
        dac.writeAnalogOutput(this.numOfAnalogOutputForCurrentLimit, currentLimitInDecimal);
        //start the motor
        int speedVoltageInDecimal = (int) (this.speedVoltageInVolt * CanOpenDAC.bitOverVolts);
        dac.writeAnalogOutput(this.numOfAnalogOutputForSpeedVoltage, speedVoltageInDecimal);

        return getName() + " is OPEN";
    }

    @Override
    public String close()  {

        //set the current limit
        int currentLimitInDecimal = (int) (this.getCurrentLimitInVolt() * CanOpenDAC.bitOverVolts);
        dac.writeAnalogOutput(this.numOfAnalogOutputForCurrentLimit, currentLimitInDecimal);
        //start the motor
        int speedVoltageInDecimal = (int) (this.getSpeedVoltageInVolt() * CanOpenDAC.bitOverVolts);
        dac.writeAnalogOutput(this.numOfAnalogOutputForSpeedVoltage, -speedVoltageInDecimal);
        return getName() + " is CLOSED";
    }

    @Override
    public String powerOff()  {
        dac.writeAnalogOutput(this.numOfAnalogOutputForCurrentLimit, 0);
        dac.writeAnalogOutput(this.numOfAnalogOutputForSpeedVoltage, 0);
        return getName() + " is POWER OFF";
    }

}

==> org-lsst-ccs-subsystem-fcs-main-4.0.12-sources.jar: org/lsst/ccs/subsystems/fcs/singlefiltertest/CanOpenLatchActuatorModule.java <==

package org.lsst.ccs.subsystems.fcs.singlefiltertest;

import org.lsst.ccs.commons.annotations.ConfigurationParameter;
import org.lsst.ccs.subsystems.fcs.drivers.CanOpenDAC;

/**
 * 
 * Used only for the single-filter-test hardware.
 * 
 * This is a model for a motor which locks or unlocks a latch. The motor is
 * driven by a CAN-CBX-AO412. We sent to the CAN-CBX-AO412 a current value.
 *
 * @author virieux
 */
public class CanOpenLatchActuatorModule extends LatchActuatorModule {

    /**
     * The DAC which controls the motor.
     */
    private CanOpenDAC dac;

    /**
     * The numero of analog output where we send the value of the current to the
     * motor. (variable)
     */
    @ConfigurationParameter
    private int numOfAnalogOutputForSpeedVoltage;

    /**
     * The numero of analog output where we send the value of the current limit
     * to the motor. current limit (fixed)
     */
    @ConfigurationParameter
    private int numOfAnalogOutputForCurrentLimit;

    /**
     * Build a new CanOpenLatchActuatorModule
     * @param currentLimitInVolt
     * @param speedVoltageInVolt
     * @param speedVoltageMinValue
     * @param speedVoltageMaxValue
     * @param dac
     * @param numOfAnalogOutputForSpeedVoltage
     * @param numOfAnalogOutputForCurrentLimit 
     */
    public CanOpenLatchActuatorModule(
            CanOpenDAC dac,
            double currentLimitInVolt,
            double speedVoltageInVolt,
            int speedVoltageMinValue,
            int speedVoltageMaxValue,
            int numOfAnalogOutputForSpeedVoltage,
            int numOfAnalogOutputForCurrentLimit) {
        super(currentLimitInVolt, speedVoltageInVolt, speedVoltageMinValue, speedVoltageMaxValue);
        this.dac = dac;
        this.numOfAnalogOutputForSpeedVoltage = numOfAnalogOutputForSpeedVoltage;
        this.numOfAnalogOutputForCurrentLimit = numOfAnalogOutputForCurrentLimit;
    }

    public void setNumOfAnalogOutputForSpeedVoltage(int numOfAnalogOutputForSpeedVoltage) {
        this.numOfAnalogOutputForSpeedVoltage = numOfAnalogOutputForSpeedVoltage;
    }

    public void setNumOfAnalogOutputForCurrentLimit(int numOfAnalogOutputForCurrentLimit) {
        this.numOfAnalogOutputForCurrentLimit = numOfAnalogOutputForCurrentLimit;
    }

    @Override
    public String open()  {

        //set the current limit
        int currentLimitInDecimal = (int) (this.currentLimitInVolt * CanOpenDAC.bitOverVolts);
        dac.writeAnalogOutput(this.numOfAnalogOutputForCurrentLimit, currentLimitInDecimal);
        //start the motor
        int speedVoltageInDecimal = (int) (this.speedVoltageInVolt * CanOpenDAC.bitOverVolts);
        dac.writeAnalogOutput(this.numOfAnalogOutputForSpeedVoltage, speedVoltageInDecimal);

        return name + " is OPEN";
    }

    @Override
    public String close()  {

        //set the current limit
        int currentLimitInDecimal = (int) (this.getCurrentLimitInVolt() * CanOpenDAC.bitOverVolts);
        dac.writeAnalogOutput(this.numOfAnalogOutputForCurrentLimit, currentLimitInDecimal);
        //start the motor
        int speedVoltageInDecimal = (int) (this.getSpeedVoltageInVolt() * CanOpenDAC.bitOverVolts);
        dac.writeAnalogOutput(this.numOfAnalogOutputForSpeedVoltage, -speedVoltageInDecimal);
        return name + " is CLOSED";
    }

    @Override
    public String powerOff()  {
        dac.writeAnalogOutput(this.numOfAnalogOutputForCurrentLimit, 0);
        dac.writeAnalogOutput(this.numOfAnalogOutputForSpeedVoltage, 0);
        return name + " is POWER OFF";
    }

}
